@@ -23,6 +23,7 @@ const EvView = imports.gi.EvinceView;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const Gd = imports.gi.Gd;
+const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
 const GData = imports.gi.GData;
 const GLib = imports.gi.GLib;
@@ -243,7 +244,7 @@ const CollectionIconWatcher = new Lang.Class({
                 pixbufs.push(doc.pristinePixbuf);
             });
 
-        this._pixbuf = Gd.create_collection_icon(Utils.getIconSize(), pixbufs);
+        this._pixbuf = GdPrivate.create_collection_icon(Utils.getIconSize(), pixbufs);
         this._emitRefresh();
     },
 
@@ -275,17 +276,16 @@ const DocCommon = new Lang.Class({
         this.author = null;
         this.mtime = null;
         this.resourceUrn = null;
-        this.favorite = null;
         this.pixbuf = null;
         this.pristinePixbuf = null;
         this.defaultAppName = null;
 
         this.mimeType = null;
         this.rdfType = null;
+        this.dateCreated = null;
         this.typeDescription = null;
         this.sourceName = null;
 
-        this.favorite = false;
         this.shared = false;
 
         this.collection = false;
@@ -325,7 +325,6 @@ const DocCommon = new Lang.Class({
         this.identifier = cursor.get_string(Query.QueryColumns.IDENTIFIER)[0];
         this.author = cursor.get_string(Query.QueryColumns.AUTHOR)[0];
         this.resourceUrn = cursor.get_string(Query.QueryColumns.RESOURCE_URN)[0];
-        this.favorite = cursor.get_boolean(Query.QueryColumns.FAVORITE);
 
         let mtime = cursor.get_string(Query.QueryColumns.MTIME)[0];
         if (mtime) {
@@ -339,6 +338,14 @@ const DocCommon = new Lang.Class({
         this.rdfType = cursor.get_string(Query.QueryColumns.RDFTYPE)[0];
         this._updateInfoFromType();
 
+        let dateCreated = cursor.get_string(Query.QueryColumns.DATE_CREATED)[0];
+        if (dateCreated) {
+            let timeVal = GLib.time_val_from_iso8601(dateCreated)[1];
+            this.dateCreated = timeVal.tv_sec;
+        } else {
+            this.dateCreated = -1;
+        }
+
         // sanitize
         if (!this.uri)
             this.uri = '';
@@ -349,7 +356,7 @@ const DocCommon = new Lang.Class({
         if (title && title != '')
             this.name = title;
         else if (filename)
-            this.name = Gd.filename_strip_extension(filename);
+            this.name = GdPrivate.filename_strip_extension(filename);
         else
             this.name = '';
 
@@ -444,13 +451,13 @@ const DocCommon = new Lang.Class({
             this.thumbnailed = false;
 
             // try to create the thumbnail
-            Gd.queue_thumbnail_job_for_file_async(this._file,
-                                                  Lang.bind(this, this._onQueueThumbnailJob));
+            GdPrivate.queue_thumbnail_job_for_file_async(this._file,
+                                                         Lang.bind(this, this._onQueueThumbnailJob));
         }
     },
 
     _onQueueThumbnailJob: function(object, res) {
-        let thumbnailed = Gd.queue_thumbnail_job_for_file_finish(res);
+        let thumbnailed = GdPrivate.queue_thumbnail_job_for_file_finish(res);
 
         if (!thumbnailed) {
             this._failedThumbnailing = true;
@@ -536,10 +543,6 @@ const DocCommon = new Lang.Class({
 
         activeItem = Global.searchCategoryManager.getActiveItem();
 
-        if (this.favorite &&
-            (!activeItem ||
-             (activeItem.id != Searchbar.SearchCategoryStock.FAVORITES)))
-            emblemIcons.push(this._createSymbolicEmblem('emblem-favorite'));
         if (this.shared &&
             (!activeItem ||
              (activeItem.id != Searchbar.SearchCategoryStock.SHARED)))
@@ -570,7 +573,7 @@ const DocCommon = new Lang.Class({
 
         if (this.thumbnailed) {
             let [ slice, border ] = Utils.getThumbnailFrameBorder();
-            this.pixbuf = Gd.embed_image_in_frame(pixbuf,
+            this.pixbuf = GdPrivate.embed_image_in_frame(pixbuf,
                 Path.ICONS_DIR + 'thumbnail-frame.png',
                 slice, border);
         } else {
@@ -613,10 +616,6 @@ const DocCommon = new Lang.Class({
             }));
     },
 
-    setFavorite: function(favorite) {
-        TrackerUtils.setFavorite(this.id, favorite, null);
-    },
-
     getWhere: function() {
         let retval = '';
 
@@ -654,10 +653,10 @@ const LocalDocument = new Lang.Class({
     },
 
     load: function(cancellable, callback) {
-        Gd.pdf_loader_load_uri_async(this.uri, cancellable, Lang.bind(this,
+        GdPrivate.pdf_loader_load_uri_async(this.uri, cancellable, Lang.bind(this,
             function(source, res) {
                 try {
-                    let docModel = Gd.pdf_loader_load_uri_finish(res);
+                    let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
                     callback(this, docModel, null);
                 } catch (e) {
                     callback(this, null, e);
@@ -725,10 +724,10 @@ const GoogleDocument = new Lang.Class({
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
-                    Gd.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
+                    GdPrivate.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
-                                let docModel = Gd.pdf_loader_load_uri_finish(res);
+                                let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
                                 callback(this, docModel, null);
                             } catch (e) {
                                 // report the outmost error only
@@ -739,11 +738,11 @@ const GoogleDocument = new Lang.Class({
                     return;
                 }
 
-                Gd.pdf_loader_load_gdata_entry_async
+                GdPrivate.pdf_loader_load_gdata_entry_async
                     (entry, service, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
-                                let docModel = Gd.pdf_loader_load_uri_finish(res);
+                                let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
                                 callback(this, docModel, null);
                             } catch (e) {
                                 callback(this, null, e);
@@ -773,46 +772,6 @@ const GoogleDocument = new Lang.Class({
         this.parent(cursor);
     },
 
-    setFavorite: function(favorite) {
-        this.parent(favorite);
-
-        this._createGDataEntry(null, Lang.bind(this,
-            function(entry, service, exception) {
-                if (!entry) {
-                    log('Unable to call setFavorite on ' + this.name + ': ' + exception.toString());
-                    return;
-                }
-
-                let starred = null;
-                let categories = entry.get_categories();
-                categories.forEach(
-                    function(category) {
-                        if (category.scheme == _GOOGLE_DOCS_SCHEME_LABELS &&
-                            category.term == _GOOGLE_DOCS_TERM_STARRED)
-                            starred = category;
-                    });
-
-                if (!starred) {
-                    starred = new GData.Category({ scheme: _GOOGLE_DOCS_SCHEME_LABELS,
-                                                   term: _GOOGLE_DOCS_TERM_STARRED });
-                    entry.add_category(starred);
-                }
-
-                starred.set_label(favorite ? 'starred' : '');
-
-                service.update_entry_async
-                    (service.get_primary_authorization_domain(),
-                     entry, null, Lang.bind(this,
-                         function(service, res) {
-                             try {
-                                 service.update_entry_finish(res);
-                             } catch (e) {
-                                 log('Unable to call setFavorite on ' + this.name + ': ' + e.toString());
-                             }
-                         }));
-            }));
-    },
-
     canTrash: function() {
         return false;
     }
@@ -864,10 +823,10 @@ const SkydriveDocument = new Lang.Class({
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
-                    Gd.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
+                    GdPrivate.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
-                                let docModel = Gd.pdf_loader_load_uri_finish(res);
+                                let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
                                 callback(this, docModel, null);
                             } catch (e) {
                                 // report the outmost error only
@@ -878,11 +837,11 @@ const SkydriveDocument = new Lang.Class({
                     return;
                 }
 
-                Gd.pdf_loader_load_zpj_entry_async
+                GdPrivate.pdf_loader_load_zpj_entry_async
                     (entry, service, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
-                                let docModel = Gd.pdf_loader_load_zpj_entry_finish(res);
+                                let docModel = GdPrivate.pdf_loader_load_zpj_entry_finish(res);
                                 callback(this, docModel, null);
                             } catch (e) {
                                 callback(this, null, e);
@@ -906,9 +865,6 @@ const SkydriveDocument = new Lang.Class({
         this.typeDescription = description;
     },
 
-    setFavorite: function(favorite) {
-    },
-
     canTrash: function() {
         return false;
     }
@@ -1077,10 +1033,10 @@ const DocumentManager = new Lang.Class({
         let evDoc = docModel.get_document();
         let file = Gio.File.new_for_uri(evDoc.get_uri());
 
-        if (!Gd.is_metadata_supported_for_file(file))
+        if (!GdPrivate.is_metadata_supported_for_file(file))
             return;
 
-        let metadata = new Gd.Metadata({ file: file });
+        let metadata = new GdPrivate.Metadata({ file: file });
 
         // save current page in metadata
         let [res, val] = metadata.get_int('page');
