@@ -491,8 +491,8 @@ const OverviewSearchbar = new Lang.Class({
     },
 
     createSearchWidgets: function() {
-        this._searchContainer = new Gd.MarginContainer({ min_margin: 6,
-                                                         max_margin: 64 });
+        this._searchContainer = new Gd.MarginContainer({ min_margin: 64,
+                                                         max_margin: 128 });
         this._box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._searchContainer.add(this._box);
 
@@ -601,6 +601,14 @@ const OverviewSearchbar = new Lang.Class({
 
     hide: function() {
         this._dropdownButton.set_active(false);
+
+        // clear all the search properties when hiding the entry
+        this._searchEntry.set_text('');
+
+        Global.searchTypeManager.setActiveItemById('all');
+        Global.searchMatchManager.setActiveItemById('all');
+        Global.sourceManager.setActiveItemById('all');
+
         this.parent();
     }
 });
